Summary: Multi-Level Intermediate Representation Overview
Name: mlir
Version: 17.0.6
Release: 1%{?dist}
%global maj_ver %(echo %{version} | cut -d. -f1)
%global mlir_srcdir mlir-%{version}.src
License: Apache-2.0 WITH LLVM-exception
URL: http://mlir.llvm.org
Source0: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/%{mlir_srcdir}.tar.xz

Patch1: 0001-mlir-python-Reuse-the-library-directory.patch

BuildRequires: clang cmake ninja-build zlib-devel python3-lit gnupg2
BuildRequires: llvm-devel = %{version}
BuildRequires: llvm-cmake-utils = %{version}
BuildRequires: llvm-googletest = %{version}
BuildRequires: llvm-test = %{version}


%description
The MLIR project is a novel approach to building reusable and extensible
compiler infrastructure. MLIR aims to address software fragmentation,
improve compilation for heterogeneous hardware, significantly reduce
the cost of building domain specific compilers, and aid in connecting
existing compilers together.

%package static
Summary: MLIR static files
Requires: %{name} = %{version}-%{release}

%description static
MLIR static files.

%package devel
Summary: MLIR development files
Requires: %{name} = %{version}-%{release}
Requires: %{name}-static = %{version}-%{release}

%description devel
MLIR development files.

%prep
%autosetup -n %{mlir_srcdir} -p2

%build

# Limit dwz resource usage on aarch 64
%global _dwz_low_mem_die_limit_aarch64 1
%global _dwz_max_die_limit_aarch64 1000000

%cmake  -GNinja \
        -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DCMAKE_SKIP_RPATH=ON \
        -DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
        -DLLVM_BUILD_LLVM_DYLIB=ON \
        -DCMAKE_PREFIX_PATH=%{_libdir}/cmake/llvm/ \
        -DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
        -DLLVM_THIRD_PARTY_DIR=%{_datadir}/llvm/src/utils \
        -DLLVM_COMMON_CMAKE_UTILS=%{_datadir}/llvm/cmake \
        -DLLVM_BUILD_TOOLS:BOOL=ON \
        -DLLVM_BUILD_UTILS:BOOL=ON \
        -DMLIR_INCLUDE_DOCS:BOOL=ON \
        -DMLIR_INCLUDE_TESTS:BOOL=ON \
        -DMLIR_INCLUDE_INTEGRATION_TESTS:BOOL=OFF \
        -DBUILD_SHARED_LIBS=OFF \
        -DMLIR_INSTALL_AGGREGATE_OBJECTS=OFF \
        -DMLIR_BUILD_MLIR_C_DYLIB=ON \
        -DLLVM_LIBDIR_SUFFIX=64
export LD_LIBRARY_PATH=%{_builddir}/%{mlir_srcdir}/%{name}/%{_build}/%{_lib}
%cmake_build

%install
%cmake_install

%check
rm -rf test/mlir-tblgen

export LD_LIBRARY_PATH=%{buildroot}/%{_libdir}
%__cmake --build "%{__cmake_builddir}" -j2 --verbose --target check-mlir

%files
%license LICENSE.TXT
%{_libdir}/libMLIR*.so.%{maj_ver}*
%{_libdir}/libmlir_async_runtime.so.%{maj_ver}*
%{_libdir}/libmlir_c_runner_utils.so.%{maj_ver}*
%{_libdir}/libmlir_float16_utils.so.%{maj_ver}*
%{_libdir}/libmlir_runner_utils.so.%{maj_ver}*

%files static
%{_libdir}/libMLIR*.a

%files devel
%{_bindir}/mlir-cpu-runner
%{_bindir}/mlir-linalg-ods-yaml-gen
%{_bindir}/mlir-lsp-server
%{_bindir}/mlir-opt
%{_bindir}/mlir-pdll
%{_bindir}/mlir-pdll-lsp-server
%{_bindir}/mlir-reduce
%{_bindir}/mlir-tblgen
%{_bindir}/mlir-translate
%{_bindir}/tblgen-lsp-server
%{_libdir}/libMLIR*.so
%{_libdir}/libmlir_async_runtime.so
%{_libdir}/libmlir_c_runner_utils.so
%{_libdir}/libmlir_float16_utils.so
%{_libdir}/libmlir_runner_utils.so
%{_includedir}/mlir
%{_includedir}/mlir-c
%{_libdir}/cmake/mlir

%changelog
* Mon Dec 18 2023 Upgrade Robot <upbot@opencloudos.org> - 17.0.6-1
- Upgrade to version 17.0.6

* Wed Nov 08 2023 Zhao Zhen <jeremiazhao@tencent.com> - 16.0.6-3
- fixed CVE-2023-29941 

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 16.0.6-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Sep 07 2023 kianli <kianli@tencent.com> - 16.0.6-1
- Initial build

